@@ -86,24 +86,17 @@ class TestITListener(object):
                     print(f'The name of Test-run has been established: {self.testrun_name}')
         self.requests = Api(url, private_token, proxy=proxy)
 
-    @pytest.hookimpl
-    def pytest_configure(self, config):
-        if not hasattr(config, "workerinput") and not hasattr(self, "testrun_id"):
-            config.testrun_id = self.requests.create_testrun(
-                JSONFixture.create_testrun(
-                    self.project_id,
-                    f'{self.testrun_name if hasattr(self, "testrun_name") else "LocalRun"} {datetime.today().strftime("%d %b %Y %H:%M:%S")}'))
-            self.requests.testrun_activity(config.testrun_id, 'start')
-
     @pytest.hookimpl
     def pytest_configure_node(self, node):
         if not hasattr(self, "testrun_id"):
             node.workerinput["testrun_id"] = pickle.dumps(node.config.testrun_id)
 
     @pytest.hookimpl
-    def pytest_collection_modifyitems(self, session, config, items):
+    def pytest_collection_modifyitems(self, config, items):
         index = 0
-        new_items = []
+        selected_items = []
+        deselected_items = []
+        resolved_autotests = []
         plugin_info = config.pluginmanager.list_plugin_distinfo()
 
         for plugin, dist in plugin_info:
@@ -112,17 +105,24 @@ class TestITListener(object):
                 self.pytest_check_get_failures = check_methods.get_failures
                 break
 
-        if not hasattr(self, "testrun_id"):
-            self.testrun_id = pickle.loads(config.workerinput["testrun_id"]) if\
-                hasattr(config, 'workerinput') else config.testrun_id
+        if hasattr(self, "testrun_id"):
+            self.project_id, json_points = self.requests.get_testrun(
+                self.testrun_id)
 
-        self.project_id, json_points = self.requests.get_testrun(
-            self.testrun_id)
-
-        resolved_autotests = autotests_parser(json_points, self.configuration_id)
+            resolved_autotests = autotests_parser(json_points, self.configuration_id)
 
         for item in items:
             if hasattr(item.function, 'test_external_id'):
+                if not hasattr(self, "testrun_id"):
+                    if not hasattr(config, "workerinput"):
+                        config.testrun_id = self.requests.create_testrun(
+                            JSONFixture.create_testrun(
+                                self.project_id,
+                                f'{self.testrun_name if hasattr(self, "testrun_name") else "LocalRun"} {datetime.today().strftime("%d %b %Y %H:%M:%S")}'))
+                        self.requests.testrun_activity(config.testrun_id, 'start')
+
+                    self.testrun_id = pickle.loads(config.workerinput["testrun_id"]) if \
+                        hasattr(config, 'workerinput') else config.testrun_id
 
                 if item.own_markers:
                     for mark in item.own_markers:
@@ -146,12 +146,13 @@ class TestITListener(object):
 
                 if resolved_autotests:
                     if item.test_external_id in resolved_autotests:
-                        new_items.append(item)
+                        selected_items.append(item)
         if resolved_autotests:
-            if not new_items:
+            if not selected_items:
                 print('The specified tests were not found!')
                 raise SystemExit
-            session.items = new_items
+            config.hook.pytest_deselected(items=deselected_items)
+            items[:] = selected_items
 
     @pytest.hookimpl
     def pytest_runtest_protocol(self, item):
@@ -273,7 +274,7 @@ class TestITListener(object):
                             autotest[0]['classname'],
                             autotest[0]['title'],
                             autotest[0]['description'],
-                            autotest[0]['links'],
+                            data_item['links'],
                             autotest[0]['labels']
                         )
                     )
