@@ -10,8 +10,8 @@ from testit_adapter_pytest import TestITPluginManager
 def inner(function):
     @wraps(function)
     def wrapper(*args, **kwargs):
-        if hasattr(TestITPluginManager.get_plugin_manager().hook, 'add_parameters') and kwargs:
-            TestITPluginManager.get_plugin_manager().hook.add_parameters(parameters=kwargs)
+        if hasattr(TestITPluginManager.get_plugin_manager().hook, 'add_properties') and kwargs:
+            TestITPluginManager.get_plugin_manager().hook.add_properties(properties=kwargs)
         function(*args, **kwargs)
         return function
     return wrapper
